@@ -3,10 +3,10 @@
 
 import time
 import board
-import busio
 import adafruit_mprls
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
 
 # Simplest use, connect to default over I2C
 mpr = adafruit_mprls.MPRLS(i2c, psi_min=0, psi_max=25)
